@@ -16,13 +16,11 @@ import click
 from rqalpha import cli
 
 __config__ = {
-    # A股最小手续费
+    # 股票最小手续费，单位元
     "cn_stock_min_commission": 5,
-    # 港股最小手续费
-    "hk_stock_min_commission": 50,
-    # 设置手续费乘数，默认为1
+    # 佣金倍率，即在默认的手续费率基础上按该倍数进行调整，股票的默认佣金为万八，期货默认佣金因合约而异
     "commission_multiplier": 1,
-    # 印花税乘数，默认为1
+    # 印花倍率，即在默认的印花税基础上按该倍数进行调整，股票默认印花税为千分之一，单边收取
     "tax_multiplier": 1,
 }
 
@@ -46,16 +44,6 @@ cli.commands['run'].params.append(
     )
 )
 
-
-cli.commands['run'].params.append(
-    click.Option(
-        ('-hksmc', '--hk-stock-min-commission', cli_prefix + 'hk_stock_min_commission'),
-        type=click.FLOAT,
-        help="[sys_simulation] set minimum commission in Hong Kong stock trades."
-    )
-)
-
-
 # [deprecated]
 cli.commands['run'].params.append(
     click.Option(
